#ifndef EL__ECMASCRIPT_MUJS_HISTORY_H
#define EL__ECMASCRIPT_MUJS_HISTORY_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

int mjs_history_init(js_State *J);

#ifdef __cplusplus
}
#endif

#endif
